Translate Toolkit 1.4.0 — Translate Toolkit 2.5.0 documentation

# Translate Toolkit 1.4.0

Released on 27 August 2009

## Java and Mozilla .properties

Unusual keys, separators and spacing should all be handled correctly now. Some Mozilla .properties files might now have changed. Regenerate your Mozilla l10n files from fresh POT files without any changes to your PO files to ensure that you can see and review these changes.

## Hashing in podebug

The `--hash` option in podebug has been replaced by a format specifier %h to be able to better control the positioning of the hash value.